summaryrefslogtreecommitdiff
path: root/include/ruby/impl/intern/variable.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/intern/variable.h')
-rw-r--r--include/ruby/impl/intern/variable.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/ruby/impl/intern/variable.h b/include/ruby/impl/intern/variable.h
index 6885448e8b..ea5fd84270 100644
--- a/include/ruby/impl/intern/variable.h
+++ b/include/ruby/impl/intern/variable.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_INTERN_VARIABLE_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_INTERN_VARIABLE_H
+#ifndef RBIMPL_INTERN_VARIABLE_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_INTERN_VARIABLE_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -25,7 +25,7 @@
#include "ruby/impl/value.h"
#include "ruby/st.h"
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
/* variable.c */
VALUE rb_mod_name(VALUE);
@@ -66,7 +66,7 @@ VALUE rb_const_get_from(VALUE, ID);
void rb_const_set(VALUE, ID, VALUE);
VALUE rb_const_remove(VALUE, ID);
#if 0 /* EXPERIMENTAL: remove if no problem */
-RUBY3_ATTR_NORETURN()
+RBIMPL_ATTR_NORETURN()
VALUE rb_mod_const_missing(VALUE,VALUE);
#endif
VALUE rb_cvar_defined(VALUE, ID);
@@ -78,6 +78,6 @@ void rb_define_class_variable(VALUE, const char*, VALUE);
VALUE rb_mod_class_variables(int, const VALUE*, VALUE);
VALUE rb_mod_remove_cvar(VALUE, VALUE);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-#endif /* RUBY3_INTERN_VARIABLE_H */
+#endif /* RBIMPL_INTERN_VARIABLE_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file